==> EnhancedXSPF-0.4.zip: EnhancedXSPF/lang/ext/nb_NO.php <==
<?php
$lang['friendlyname'] = 'Enhanced XSPF ';
$lang['postinstall'] = 'Modulen ble installert';
$lang['postuninstall'] = 'Modulen er vellykket avinstallert';
$lang['really_uninstall'] = 'Er du sikekr p&aring; at du vil avinstallere denne modulen?';
$lang['audit_module_install'] = 'Modul versjon %s installert.';
$lang['audit_module_upgrade'] = 'Modulen er oppgradert til versjon %s.';
$lang['audit_module_uninstall'] = 'Modul avinstallert.';
$lang['audit_admin_playlist_added'] = 'Spilleliste lagt til';
$lang['audit_admin_playlist_changed'] = 'Spilleliste endret';
$lang['audit_admin_playlist_songs_saved'] = 'Spilleliste sanger lagret';
$lang['audit_admin_playlist_deleted'] = 'Spilleliste slettet';
$lang['audit_admin_prefs_changed'] = 'Modul innstillinger endret';
$lang['title_admintab_prefs'] = 'Modul innstillinger';
$lang['title_admintab_songs'] = 'Sanger';
$lang['title_admintab_playlists'] = 'Spillelister';
$lang['id'] = 'Id ';
$lang['name'] = 'Navn';
$lang['description'] = 'Beskrivelse';
$lang['songs'] = 'Sanger';
$lang['playlist'] = 'Spilleliste';
$lang['title_link_add_playlist'] = 'Legg til spilleliste';
$lang['title_link_edit_songs'] = 'Endre sanger';
$lang['title_link_add_uploads_categories'] = 'Legg til Opplastingskategorier';
$lang['title_songs_in_playlist'] = 'Sanger i spillelista';
$lang['title_available_songs'] = 'Tilgjengelige sanger';
$lang['alert_delete_playlist'] = 'Slett spilleliste %s?';
$lang['header_default_player_options'] = 'Standard spiller innstillinger';
$lang['header_add_playlist'] = 'Legg til spilleliste';
$lang['header_add_playlist_songs'] = 'Legg til spilleliste sanger';
$lang['header_edit_playlist'] = 'Rediger spilleliste';
$lang['header_edit_playlist_songs'] = 'Rediger spilleliste sanger';
$lang['header_admin_playlists'] = 'Behandle spillelister';
$lang['dropdown_item_player_slim'] = 'Slank';
$lang['dropdown_item_player_extended'] = 'Utvidet';
$lang['label_admin_prefs_extended_player_url'] = 'utvidet_spiller_url';
$lang['label_admin_prefs_slim_player_url'] = 'slank_spiller_url';
$lang['label_admin_prefs_player_width'] = 'spiller_bredde';
$lang['label_admin_prefs_slim_player_height'] = 'slank_spiller_h&oslash;yde';
$lang['label_admin_prefs_extended_player_height'] = 'utvidet_spiller_h&oslash;yde';
$lang['label_admin_prefs_autoresume'] = 'autofortsett';
$lang['label_admin_prefs_autoplay'] = 'autospill';
$lang['label_admin_prefs_autoload'] = 'autolast';
$lang['label_admin_prefs_shuffle'] = 'tilfeldig';
$lang['label_admin_prefs_repeat'] = 'repeter';
$lang['label_admin_prefs_player'] = 'spiller';
$lang['label_admin_prefs_count_downloads'] = 'antall_nedlastinger';
$lang['msg_no_changes'] = 'Ingen endringer';
$lang['msg_playlist_songs_updated'] = 'oppdaterte spilleliste sanger';
$lang['msg_playlist_updated'] = 'Oppdaterte spilleliste';
$lang['msg_set_preference'] = 'Oppdaterte innstillinger %s';
$lang['msg_playlist_added'] = 'Spilleliste lagt til';
$lang['err_access_denied'] = 'Tilgang nektet. Vennligst sjekk dine rettigheter.';
$lang['err_admin_add_playlist_no_name'] = 'Feil: ingen navn oppgitt';
$lang['err_playlist_not_found'] = 'Feil: den oppgitte spillelisten ble ikke funnet';
$lang['err_uploads_module_not_installed'] = 'Feil: Opplasting(Uploads) modulen er ikke installert';
$lang['err_no_uploads_categories_defined'] = 'Feil: det er ingen opplastings kategorier';
$lang['err_no_mp3s_found'] = 'Feil: ingen .mp3 filer funnet i opplastingskategoriene';
$lang['err_no_playlist_specified'] = 'Feil: ingen spilleliste ble spesifisert';
$lang['err_no_song_specified'] = 'Feil: ingen sang (opplasting ID) ble spesifisert';
$lang['err_no_playlist_or_song_specified'] = 'Feil: ingen sang eller spilleliste parameter oppgitt';
$lang['help_drag_drop'] = 'bruk dra og slipp for &aring; legge til/fjerne sanger og for &aring; sette rekkef&oslash;lgen';
$lang['help_parameter_count_downloads'] = 'Om hver sang spilt skal telles som en nedlasting i upplastings modulen. Om satt til usann(false), vil direkte linker til MP3 filene (i opplasting/uploads katalogen) bli benyttet';
$lang['help_parameter_playlist'] = 'spilleliste id &aring; spille';
$lang['help_parameter_song'] = 'opplasting_id for &aring; spille en enkelt sang i stedet for en spilleliste';
$lang['help_parameter_song_title'] = 'Tekst som skal erstatte spillerens standard. Kun benyttet n&aring;r sang parameteren ogs&aring; er gitt.';
$lang['help_parameter_player'] = 'xspf spillerversjon &aring; benytte (slank eller utvidet)';
$lang['help_parameter_extended_player_url'] = 'url til den utvidede versjonen av xspf spilleren';
$lang['help_parameter_slim_player_url'] = 'url til den slanke versjonen av xspf spilleren';
$lang['help_parameter_player_width'] = 'bredde p&aring; spilleren i pixler';
$lang['help_parameter_slim_player_height'] = 'h&oslash;yde p&aring; den slanke spilleren i pixler';
$lang['help_parameter_extended_player_height'] = 'h&oslash;yde p&aring; den utvidede spilleren i pixler';
$lang['help_parameter_autoresume'] = 'booleansk verdi som gj&oslash;r at spilleren husker sin posisjon';
$lang['help_parameter_autoplay'] = 'booleansk verdi som gj&oslash;r at spillelisten lastes og musikken starter uten brukers innledende museklikk';
$lang['help_parameter_autoload'] = 'boolean verdi som gj&oslash;r at spillelisten lastes uten brukers innledende musklikk';
$lang['help_parameter_repeat_playlist'] = 'booleansk verdi for &aring; repetere spillelisten';
$lang['help_parameter_alpha'] = 'prosent fargeskifte, fungerer kun med tilpassede farger';
$lang['help_parameter_alphabetize'] = 'booleansk verdi for &aring; sortere spillelisten alfabetisk';
$lang['help_parameter_buffer'] = 'sekunder &aring; buffre video f&oslash;r avspilling, utelukk for automatisk';
$lang['help_parameter_color'] = 'seks tall hex verdi for &aring; endre spillerens farge';
$lang['help_parameter_gotoany'] = 'booleansk verdi som tvinger reise til ukjente URLer';
$lang['help_parameter_image'] = 'url for et jpg bilde som vises n&aring;r autospill er avsl&aring;tt';
$lang['help_parameter_info_button_text'] = 'teksten &aring; vise p&aring; informasjonslinken, <a href=http://musicplayer.sourceforge.net/test/info-test.html>see this page</a>';
$lang['help_parameter_infourl'] = 'global infolink for alle sanger, erstatter spillelisters infolinker';
$lang['help_parameter_loadurl'] = 'url linking to a text file containing all variables. cuts down on html coding and file sizes, one file can be used by many players';
$lang['help_parameter_load_message'] = 'melding vist etter autolasting';
$lang['help_parameter_main_image'] = 'global bildelink, erstatter alle spilleliste bilder';
$lang['help_parameter_mainurl'] = 'h&oslash;yre-klikk &quot;om&quot; link';
$lang['help_parameter_no_continue'] = 'booleansk verdi for &aring; sl&aring; av automatisk sang skifte';
$lang['help_parameter_player_title'] = 'tekst som erstatter spillerens standard';
$lang['help_parameter_repeat'] = 'booleansk verdi f&aring;r &aring; sl&aring; p&aring; repeter';
$lang['help_parameter_setup'] = 'boolean value to turn on special manager features such as auto-update. more to come.';
$lang['help_parameter_shuffle'] = 'booleansk verdi for &aring; sette tilfeldig';
$lang['help_parameter_start_track'] = 'spornummer for start-spor';
$lang['help_parameter_statsurl'] = 'url to an external script that can collect POST values. Can collect playSong and annotation';
$lang['help_parameter_timedisplay'] = 'numerical value to show time counter; 0:off, 1:all, 2:elapsed, 3:duration, 4:countdown';
$lang['help_parameter_useId3'] = 'boolean value that forces id3 tag use in the slim player. Can be helpful, but not recommended';
$lang['help_parameter_volume_level'] = 'startende volum niv&aring;';
$lang['event_info_XSPFSongAdded'] = 'An event generated when a song is added';
$lang['event_help_XSPFSongAdded'] = '<p>An event generated when a song is added</p>
<h4>Parameters</h4>
<ul>
<li><em>song_name</em> - The new song name</li>
</ul> 
';
$lang['event_info_XSPFSongChanged'] = 'An event generated when a song is modified';
$lang['event_help_XSPFSongChanged'] = '<p>An event generated when a song is modified</p>
<h4>Parameters</h4>
<ul>
<li><em>song_id</em> - The song id</li>
<li><em>song_name</em> - The new song name</li>
</ul> 
';
$lang['event_info_XSPFSongDeleted'] = 'An event generated when a song is deleted';
$lang['event_help_XSPFSongDeleted'] = '<p>An event generated when a song is deleted</p>
<h4>Parameters</h4>
<ul>
<li><em>song_id</em> - The song id</li>
</ul> 
';
$lang['moddescription'] = 'Enhanced XSPF Web Music Player - play MP3 on your CMS Made Simple website';
$lang['changelog'] = '<ul>
	<li>Version 0.2 Februari 2007 (dittmann). 
		<ul>
			<li>Added song parameter to play a single song</li>
			<li>Added count_downloads parameter</li>
			<li>Playlist songs can now be selected from all Uploads categories</li>
		</ul>
	</li>
	<li>Version 0.1 Januari 2007 (dittmann). 
		<ul>
		    <li>Initial module release</li>
		</ul>
	</li>
</ul>';
$lang['help'] = '<h3>What Does This Do?</h3>
<p>
	With this module you can manage a <a href=&quot;http://www.xspf.org&quot;>XSPF</a> playlist to use with a xspf music player. <a href=&quot;http://www.boutell.com/xspf/&quot;>Enhanced XSPF player</a> is provided with the module.</p>
<p>
	The module uses the Uploads &quot;Summary&quot; field as the song <title> in the playlist XPSF/XML, the &quot;Author&quot; field is used as <creator> and the &quot;Description&quot; field can be used to supply an <info> link.
</p>
<h3>How Do I Use It</h3>
<p>Upload the mp3 files you want to play using the Uploads module.</p>
<p>
	<strong>To play a single song</strong><br />
	Provide the file ID from the Uploads module as song parameter - the module call will look something like this: {cms_module module=EnhancedXSPF song=4}
<p>
	<strong>To play a playlist</strong><br />
	Create one or more playlists from the module admin and include the module in your template providing the playlist id to use - the module call will look something like this: {cms_module module=EnhancedXSPF playlist=1}
	
</p>
<p>
	<strong>Use only the playlist</strong><br />
	To download the XSPF file, or when you include the player in a frame (for playback without pauses when the page is changed) you can call the playlist seperately, providing a playlist parameter.<br />
	The playlist_url would look something like this: http://www.example.com/modules/EnhancedXSPF/playlist.xml.php?playlist=1
</p>
<h3>XSPF Player parameters</h3>
<p>
	All player parameters (see also xspf/xspfdoc.html inside the module directory) can be passed to the module and will be used in the player call.<br />
</p>
<h3>Support</h3>
<p>There is a number of resources available to help you with this module:
<ul>
<li>Additional discussion of this module may also be found in the <a href=&quot;http://forum.cmsmadesimple.org&quot;>CMS Made Simple Forums</a>.</li>
<li>The author, Dick Ittmann, can often be found as DeeEye in the <a href=&quot;http://cmsmadesimple.org/main/support/IRC&quot;>CMS IRC Channel</a>.</li>
</ul>
</p>
<p>As per the GPL, this software is provided as-is. Please read the text
of the license for the full disclaimer.</p>

<h3>Copyright and License</h3>
<p>Copyright &copy; 2007, Dick Ittmann. All Rights Are Reserved.</p>
<p>This module has been released under the <a href=&quot;http://www.gnu.org/licenses/licenses.html#GPL&quot;>GNU Public License</a>. You must agree to this license before using the module.</p>
';
?>

==> EnhancedXSPF-0.5.zip: EnhancedXSPF/lang/ext/nb_NO.php <==
<?php
$lang['friendlyname'] = 'Enhanced XSPF ';
$lang['postinstall'] = 'Modulen ble installert';
$lang['postuninstall'] = 'Modulen er vellykket avinstallert';
$lang['really_uninstall'] = 'Er du sikekr p&aring; at du vil avinstallere denne modulen?';
$lang['audit_module_install'] = 'Modul versjon %s installert.';
$lang['audit_module_upgrade'] = 'Modulen er oppgradert til versjon %s.';
$lang['audit_module_uninstall'] = 'Modul avinstallert.';
$lang['audit_admin_playlist_added'] = 'Spilleliste lagt til';
$lang['audit_admin_playlist_changed'] = 'Spilleliste endret';
$lang['audit_admin_playlist_songs_saved'] = 'Spilleliste sanger lagret';
$lang['audit_admin_playlist_deleted'] = 'Spilleliste slettet';
$lang['audit_admin_prefs_changed'] = 'Modul innstillinger endret';
$lang['title_admintab_prefs'] = 'Modul innstillinger';
$lang['title_admintab_songs'] = 'Sanger';
$lang['title_admintab_playlists'] = 'Spillelister';
$lang['id'] = 'Id ';
$lang['name'] = 'Navn';
$lang['description'] = 'Beskrivelse';
$lang['songs'] = 'Sanger';
$lang['playlist'] = 'Spilleliste';
$lang['title_link_add_playlist'] = 'Legg til spilleliste';
$lang['title_link_edit_songs'] = 'Endre sanger';
$lang['title_link_add_uploads_categories'] = 'Legg til Opplastingskategorier';
$lang['title_songs_in_playlist'] = 'Sanger i spillelista';
$lang['title_available_songs'] = 'Tilgjengelige sanger';
$lang['alert_delete_playlist'] = 'Slett spilleliste %s?';
$lang['header_module_options'] = 'Modul innstillinger';
$lang['header_parameter_defaults'] = 'Parameter standarder';
$lang['header_add_playlist'] = 'Legg til spilleliste';
$lang['header_add_playlist_songs'] = 'Legg til spilleliste sanger';
$lang['header_edit_playlist'] = 'Rediger spilleliste';
$lang['header_edit_playlist_songs'] = 'Rediger spilleliste sanger';
$lang['header_admin_playlists'] = 'Behandle spillelister';
$lang['dropdown_item_player_slim'] = 'Slank';
$lang['dropdown_item_player_extended'] = 'Utvidet';
$lang['label_admin_prefs_extended_player_url'] = 'utvidet_spiller_url';
$lang['label_admin_prefs_slim_player_url'] = 'slank_spiller_url';
$lang['label_admin_prefs_player_width'] = 'spiller_bredde';
$lang['label_admin_prefs_slim_player_height'] = 'slank_spiller_h&oslash;yde';
$lang['label_admin_prefs_extended_player_height'] = 'utvidet_spiller_h&oslash;yde';
$lang['label_admin_prefs_autoresume'] = 'autofortsett';
$lang['label_admin_prefs_autoplay'] = 'autospill';
$lang['label_admin_prefs_autoload'] = 'autolast';
$lang['label_admin_prefs_shuffle'] = 'tilfeldig';
$lang['label_admin_prefs_repeat'] = 'repeter';
$lang['label_admin_prefs_player'] = 'spiller';
$lang['label_admin_prefs_count_downloads'] = 'antall_nedlastinger';
$lang['label_admin_prefs_no_direct_downloads'] = 'ikke_direkte_nedlasting';
$lang['msg_no_changes'] = 'Ingen endringer';
$lang['msg_playlist_songs_updated'] = 'oppdaterte spilleliste sanger';
$lang['msg_playlist_updated'] = 'Oppdaterte spilleliste';
$lang['msg_set_preference'] = 'Oppdaterte innstillinger %s';
$lang['msg_playlist_added'] = 'Spilleliste lagt til';
$lang['err_access_denied'] = 'Tilgang nektet. Vennligst sjekk dine rettigheter.';
$lang['err_admin_add_playlist_no_name'] = 'Feil: ingen navn oppgitt';
$lang['err_playlist_not_found'] = 'Feil: den oppgitte spillelisten ble ikke funnet';
$lang['err_uploads_module_not_installed'] = 'Feil: Opplasting(Uploads) modulen er ikke installert';
$lang['err_no_uploads_categories_defined'] = 'Feil: det er ingen opplastings kategorier';
$lang['err_no_mp3s_found'] = 'Feil: ingen .mp3 filer funnet i opplastingskategoriene';
$lang['err_no_playlist_specified'] = 'Feil: ingen spilleliste ble spesifisert';
$lang['err_no_song_specified'] = 'Feil: ingen sang (opplasting ID) ble spesifisert';
$lang['err_no_playlist_or_song_specified'] = 'Feil: ingen sang eller spilleliste parameter oppgitt';
$lang['help_drag_drop'] = 'bruk dra og slipp for &aring; legge til/fjerne sanger og for &aring; sette rekkef&oslash;lgen';
$lang['help_parameter_count_downloads'] = 'Om hver sang spilt skal telles som en nedlasting i upplastings modulen. Om satt til usann(false), vil direkte linker til MP3 filene (i opplasting/uploads katalogen) bli benyttet';
$lang['help_parameter_no_direct_downloads'] = 'Sl&aring; p&aring; dette for &aring; hindre noen i &aring; finne lokasjonen for direkte nedlasting av dine MP3 filer ved &aring; g&aring; gjennom spillelistens XSPF/XML fil direkte. &Aring; sl&aring; p&aring; dette vil sl&aring; av tell_nedlastinger(count_downloads) parameteren (nedlastinger blir alltid tellet).';
$lang['help_parameter_playlist'] = 'spilleliste id &aring; spille';
$lang['help_parameter_song'] = 'opplasting_id for &aring; spille en enkelt sang i stedet for en spilleliste';
$lang['help_parameter_song_title'] = 'Tekst som skal erstatte spillerens standard. Kun benyttet n&aring;r sang parameteren ogs&aring; er gitt.';
$lang['help_parameter_player'] = 'xspf spillerversjon &aring; benytte (slank eller utvidet)';
$lang['help_parameter_extended_player_url'] = 'url til den utvidede versjonen av xspf spilleren';
$lang['help_parameter_slim_player_url'] = 'url til den slanke versjonen av xspf spilleren';
$lang['help_parameter_player_width'] = 'bredde p&aring; spilleren i pixler';
$lang['help_parameter_slim_player_height'] = 'h&oslash;yde p&aring; den slanke spilleren i pixler';
$lang['help_parameter_extended_player_height'] = 'h&oslash;yde p&aring; den utvidede spilleren i pixler';
$lang['help_parameter_autoresume'] = 'booleansk verdi som gj&oslash;r at spilleren husker sin posisjon';
$lang['help_parameter_autoplay'] = 'booleansk verdi som gj&oslash;r at spillelisten lastes og musikken starter uten brukers innledende museklikk';
$lang['help_parameter_autoload'] = 'boolean verdi som gj&oslash;r at spillelisten lastes uten brukers innledende musklikk';
$lang['help_parameter_repeat_playlist'] = 'booleansk verdi for &aring; repetere spillelisten';
$lang['help_parameter_alpha'] = 'prosent fargeskifte, fungerer kun med tilpassede farger';
$lang['help_parameter_alphabetize'] = 'booleansk verdi for &aring; sortere spillelisten alfabetisk';
$lang['help_parameter_buffer'] = 'sekunder &aring; buffre video f&oslash;r avspilling, utelukk for automatisk';
$lang['help_parameter_color'] = 'seks tall hex verdi for &aring; endre spillerens farge';
$lang['help_parameter_gotoany'] = 'booleansk verdi som tvinger reise til ukjente URLer';
$lang['help_parameter_image'] = 'url for et jpg bilde som vises n&aring;r autospill er avsl&aring;tt';
$lang['help_parameter_info_button_text'] = 'teksten &aring; vise p&aring; informasjonslinken, <a href=http://musicplayer.sourceforge.net/test/info-test.html>see this page</a>';
$lang['help_parameter_infourl'] = 'global infolink for alle sanger, erstatter spillelisters infolinker';
$lang['help_parameter_loadurl'] = 'url link til en tekstfil som inneholder alle variablene. Korter ned p&aring; html kodingen og filst&oslash;rrelser, &eacute;n fil kan bli brukt av mange spillere';
$lang['help_parameter_load_message'] = 'melding vist etter autolasting';
$lang['help_parameter_main_image'] = 'global bildelink, erstatter alle spilleliste bilder';
$lang['help_parameter_mainurl'] = 'h&oslash;yre-klikk &quot;om&quot; link';
$lang['help_parameter_no_continue'] = 'booleansk verdi for &aring; sl&aring; av automatisk sang skifte';
$lang['help_parameter_player_title'] = 'tekst som erstatter spillerens standard';
$lang['help_parameter_repeat'] = 'booleansk verdi f&aring;r &aring; sl&aring; p&aring; repeter';
$lang['help_parameter_setup'] = 'boolean value to turn on special manager features such as auto-update. more to come.';
$lang['help_parameter_shuffle'] = 'booleansk verdi for &aring; sette tilfeldig(shuffle)';
$lang['help_parameter_start_track'] = 'spornummer for start-spor';
$lang['help_parameter_statsurl'] = 'link til et eksternt skript om kan samle POST verdier. Kan samle playSong og annotering';
$lang['help_parameter_timedisplay'] = 'nummerisk verdi for hvordan tidstelleren skal vises; 0:av, 1:alt, 2:tid_l&oslash;pt, 3:lengde, 4:nedtelling';
$lang['help_parameter_useId3'] = 'booleansk verdi som forserer id3 tagg bruk i den slanke avspilleren. Kan v&aelig;re kjekt, men ikke anbefalt';
$lang['help_parameter_volume_level'] = 'startende volum niv&aring;';
$lang['event_info_XSPFSongAdded'] = 'En hendelse generert n&aring;r en sang er lagt til';
$lang['event_help_XSPFSongAdded'] = '<p>An event generated when a song is added</p>
<h4>Parameters</h4>
<ul>
<li><em>song_name</em> - The new song name</li>
</ul> 
';
$lang['event_info_XSPFSongChanged'] = 'En hendelse generert n&aring;r en sang er endret';
$lang['event_help_XSPFSongChanged'] = '<p>An event generated when a song is modified</p>
<h4>Parameters</h4>
<ul>
<li><em>song_id</em> - The song id</li>
<li><em>song_name</em> - The new song name</li>
</ul> 
';
$lang['event_info_XSPFSongDeleted'] = 'En hendelse generert n&aring;r en sang er slettet';
$lang['event_help_XSPFSongDeleted'] = '<p>An event generated when a song is deleted</p>
<h4>Parameters</h4>
<ul>
<li><em>song_id</em> - The song id</li>
</ul> 
';
$lang['moddescription'] = 'Enhanced XSPF Web Music Player - spill MP3 p&aring; din CMS Made Simple nettside';
$lang['changelog'] = '<ul>
	<li>Version 0.4 Februari 2007 (dittmann). 
		<ul>
			<li>Fixed the playlist not working correctly with CMS Made Simple 1.0.2 and 1.0.3</li>
		</ul>
	</li>
	<li>Version 0.3 Februari 2007 (dittmann). 
		<ul>
			<li>Added support for images using Uploads thumbnails</li>
		</ul>
	</li>
	<li>Version 0.2 Februari 2007 (dittmann). 
		<ul>
			<li>Added song parameter to play a single song</li>
			<li>Added count_downloads parameter</li>
			<li>Playlist songs can now be selected from all Uploads categories</li>
			<li>Added no_direct_downloads preference</li>
		</ul>
	</li>
	<li>Version 0.1 Januari 2007 (dittmann). 
		<ul>
		    <li>Initial module release</li>
		</ul>
	</li>
</ul>';
$lang['help'] = '<h3>What Does This Do?</h3>
<p>
	With this module you can manage a <a href=&quot;http://www.xspf.org&quot;>XSPF</a> playlist to use with a xspf music player. <a href=&quot;http://www.boutell.com/xspf/&quot;>Enhanced XSPF player</a> is provided with the module.</p>
<p>
	The module uses the Uploads &quot;Summary&quot; field as the song &amp;lt;title> in the playlist XPSF/XML, the &quot;Author&quot; field is used as &amp;lt;creator> and the &quot;Description&quot; field can be used to supply an &amp;lt;info> link.<br />
	When a thumbnail is used for the MP3 in the Uploads module (must be JPG) it will be used as &amp;lt;image>.
</p>
<h3>How Do I Use It</h3>
<p>
	Upload the mp3 files you want to play (and their thumbnails) using the Uploads module. Then include the module somewhere in your template(s) (or on a single page), using either the song or the playlist parameter.
</p>
<p>
	<strong>To play a single song</strong><br />
	Provide the file ID from the Uploads module as song parameter - the module call will look something like this: {cms_module module=EnhancedXSPF song=4}
<p>
	<strong>To play a playlist</strong><br />
	Create one or more playlists from the module admin and provide the playlist ID as playlist parameter - the module call will look something like this: {cms_module module=EnhancedXSPF playlist=1}
	
</p>
<p>
	<strong>Use only the playlist</strong><br />
	To download the XSPF file, or to use the playlist from outside CMSMS - for example from a frame (for playback without pauses when the page is changed) - you can call the playlist seperately, providing a playlist parameter.<br />
	The playlist_url would look something like this: http://www.example.com/modules/EnhancedXSPF/playlist.xml.php?playlist=1<br />
	To disable download counts: http://www.example.com/modules/EnhancedXSPF/playlist.xml.php?playlist=1&amp;count_downloads=0 (note: this will not work when the module no_direct_downloads preference is set from the admin).
</p>
<h3>XSPF Player parameters</h3>
<p>
	All player parameters (see also xspf/xspfdoc.html inside the module directory) can be passed to the module and will be used in the player call.<br />
</p>
<h3>Support</h3>
<p>There is a number of resources available to help you with this module:
<ul>
<li>Additional discussion of this module may also be found in the <a href=&quot;http://forum.cmsmadesimple.org&quot;>CMS Made Simple Forums</a>.</li>
<li>The author, Dick Ittmann, can often be found as DeeEye in the <a href=&quot;http://cmsmadesimple.org/main/support/IRC&quot;>CMS IRC Channel</a>.</li>
</ul>
</p>
<p>As per the GPL, this software is provided as-is. Please read the text
of the license for the full disclaimer.</p>

<h3>Copyright and License</h3>
<p>Copyright &amp;copy; 2007, Dick Ittmann. All Rights Are Reserved.</p>
<p>This module has been released under the <a href=&quot;http://www.gnu.org/licenses/licenses.html#GPL&quot;>GNU Public License</a>. You must agree to this license before using the module.</p>';
?>
